@@ -1,9 +1,10 @@
 package CPAN::Meta::Check;
-$CPAN::Meta::Check::VERSION = '0.011';
+# vi:noet:sts=2:sw=2:ts=2
+$CPAN::Meta::Check::VERSION = '0.015';
 use strict;
 use warnings;
 
-use Exporter 5.57 'import';
+use base 'Exporter';
 our @EXPORT = qw//;
 our @EXPORT_OK = qw/check_requirements requirements_for verify_dependencies/;
 our %EXPORT_TAGS = (all => [ @EXPORT, @EXPORT_OK ] );
@@ -19,9 +20,11 @@ sub _check_dep {
 
 	my $metadata = Module::Metadata->new_from_module($module, inc => $dirs);
 	return "Module '$module' is not installed" if not defined $metadata;
+
 	my $version = eval { $metadata->version };
-	return "Missing version info for module '$module'" if $reqs->requirements_for_module($module) and not $version;
-	return sprintf 'Installed version (%s) of %s is not in range \'%s\'', $version, $module, $reqs->requirements_for_module($module) if not $reqs->accepts_module($module, $version || 0);
+	return sprintf 'Installed version (%s) of %s is not in range \'%s\'',
+			(defined $version ? $version : 'undef'), $module, $reqs->requirements_for_module($module)
+		if not $reqs->accepts_module($module, $version || 0);
 	return;
 }
 
@@ -29,9 +32,11 @@ sub _check_conflict {
 	my ($reqs, $module, $dirs) = @_;
 	my $metadata = Module::Metadata->new_from_module($module, inc => $dirs);
 	return if not defined $metadata;
+
 	my $version = eval { $metadata->version };
-	return "Missing version info for module '$module'" if not $version;
-	return sprintf 'Installed version (%s) of %s is in range \'%s\'', $version, $module, $reqs->requirements_for_module($module) if $reqs->accepts_module($module, $version);
+	return sprintf 'Installed version (%s) of %s is in range \'%s\'',
+			(defined $version ? $version : 'undef'), $module, $reqs->requirements_for_module($module)
+		if $reqs->accepts_module($module, $version);
 	return;
 }
 
@@ -76,7 +81,7 @@ CPAN::Meta::Check - Verify requirements in a CPAN::Meta object
 
 =head1 VERSION
 
-version 0.011
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -110,8 +115,6 @@ This function returns a unified L<CPAN::Meta::Requirements|CPAN::Meta::Requireme
 
 =item * L<CPAN::Meta|CPAN::Meta>
 
-=for comment # vi:noet:sts=2:sw=2:ts=2
-
 =back
 
 =head1 AUTHOR
